#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsec
version: 3.1.11
id: parsec-3.1.11-2df9dc070a05b018377712731c5dde62
key: parse_AtBt9uDOS2NCyWnucTHV3y
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: https://github.com/aslatter/parsec
synopsis: Monadic parser combinators
description:
    Parsec is designed from scratch as an industrial-strength parser
    library.  It is simple, safe, well documented (on the package
    homepage), has extensive libraries, good error messages,
    and is fast.  It is defined as a monad transformer that can be
    stacked on arbitrary monads, and it is also parametric in the
    input stream type.
category: Parsing
author: Daan Leijen <daan@microsoft.com>, Paolo Martini <paolo@nemail.it>
exposed: True
exposed-modules:
    Text.Parsec Text.Parsec.String Text.Parsec.ByteString
    Text.Parsec.ByteString.Lazy Text.Parsec.Text Text.Parsec.Text.Lazy
    Text.Parsec.Pos Text.Parsec.Error Text.Parsec.Prim Text.Parsec.Char
    Text.Parsec.Combinator Text.Parsec.Token Text.Parsec.Expr
    Text.Parsec.Language Text.Parsec.Perm Text.ParserCombinators.Parsec
    Text.ParserCombinators.Parsec.Char
    Text.ParserCombinators.Parsec.Combinator
    Text.ParserCombinators.Parsec.Error
    Text.ParserCombinators.Parsec.Expr
    Text.ParserCombinators.Parsec.Language
    Text.ParserCombinators.Parsec.Perm
    Text.ParserCombinators.Parsec.Pos
    Text.ParserCombinators.Parsec.Prim
    Text.ParserCombinators.Parsec.Token
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/parsec-3.1.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/parsec-3.1.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/parsec-3.1.11
hs-libraries: HSparsec-3.1.11-AtBt9uDOS2NCyWnucTHV3y
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-parsec/html/parsec.haddock
haddock-html: /usr/share/doc/haskell-parsec/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
